Welcome to mirror list, hosted at ThFree Co, Russian Federation.

git.blender.org/blender.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorCampbell Barton <ideasman42@gmail.com>2018-07-15 00:55:20 +0300
committerCampbell Barton <ideasman42@gmail.com>2018-07-15 00:55:54 +0300
commit89299f66207bd278e37e9e55ade87e8989b0de3d (patch)
treed0287dd0aa7ceb3d5a7f9cb22018c0b41e76790b /release/scripts/templates_py/gizmo_operator_target.py
parent5ebebcfbfff4c218ab4101ee7f6a66617ee9b01f (diff)
WM: rename manipulator to gizmo in Python API
Diffstat (limited to 'release/scripts/templates_py/gizmo_operator_target.py')
-rw-r--r--release/scripts/templates_py/gizmo_operator_target.py12
1 files changed, 6 insertions, 6 deletions
diff --git a/release/scripts/templates_py/gizmo_operator_target.py b/release/scripts/templates_py/gizmo_operator_target.py
index ba53b5e10ff..08fe63ef0b7 100644
--- a/release/scripts/templates_py/gizmo_operator_target.py
+++ b/release/scripts/templates_py/gizmo_operator_target.py
@@ -1,15 +1,15 @@
# Example of a manipulator that activates an operator
# using the predefined dial manipulator to change the camera roll.
#
# Usage: Run this script and select a camera in the 3D view.
#
import bpy
from bpy.types import (
- ManipulatorGroup,
+ GizmoGroup,
)
-class MyCameraWidgetGroup(ManipulatorGroup):
+class MyCameraWidgetGroup(GizmoGroup):
bl_idname = "OBJECT_WGT_test_camera"
bl_label = "Object Camera Test Widget"
bl_space_type = 'VIEW_3D'
@@ -22,9 +22,9 @@ class MyCameraWidgetGroup(ManipulatorGroup):
return (ob and ob.type == 'CAMERA')
def setup(self, context):
# Run an operator using the dial manipulator
ob = context.object
- mpr = self.manipulators.new("MANIPULATOR_WT_dial_3d")
+ mpr = self.gizmos.new("GIZMO_WT_dial_3d")
props = mpr.target_set_operator("transform.rotate")
props.constraint_axis = False, False, True
props.constraint_orientation = 'LOCAL'
@@ -1,15 +1,15 @@
-# Example of a manipulator that activates an operator
-# using the predefined dial manipulator to change the camera roll.
+# Example of a gizmo that activates an operator
+# using the predefined dial gizmo to change the camera roll.
#
# Usage: Run this script and select a camera in the 3D view.
@@ -22,9 +22,9 @@ class MyCameraWidgetGroup(ManipulatorGroup):
return (ob and ob.type == 'CAMERA')
def setup(self, context):
- # Run an operator using the dial manipulator
+ # Run an operator using the dial gizmo
ob = context.object